@@ -18,7 +18,6 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
-#include "about.h"
 #include "audioplayer.h"
 #include "audioprober.h"
 #include "audiorecorder.h"
@@ -82,8 +81,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return SettingsModel::instance();
     });
 
-    qmlRegisterSingletonInstance("KRecorder", 1, 0, "AboutType", &AboutType::instance());
-
     QQmlApplicationEngine engine;
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
